@@ -416,7 +416,7 @@ def homo_stacking(X, y, create_base_estimator, Ns = [1, 2, 5], Ls = [1, 2, 5, 10
     repeat = 10 # run multiple times to get the mean
     '''
 
-    pbar = tqdm(total = ITER * len(Ns) * len(Ls), position=0, leave=True) # stay on top
+    pbar = tqdm(total = repeat * len(Ns) * len(Ls), position=0, leave=True) # stay on top
 
     plt.figure(figsize = (14, 6))
 
